@@ -23,8 +23,8 @@ class API(object):
         })
         self.token = token.json()['token']
 
-    def open_order(self,symbol, cmd, volume, price, slippage, stoploss, takeprofit):
-        params = {"symbol":symbol,"cmd":cmd,"volume":volume,"price":price,"slippage":slippage,"stoploss":stoploss,"takeprofit":takeprofit}
+    def open_order(self,symbol, cmd, volume, price, slippage, stoploss, takeprofit, comment):
+        params = {"symbol":symbol,"cmd":cmd,"volume":volume,"price":price,"slippage":slippage,"stoploss":stoploss,"takeprofit":takeprofit,"comment":comment}
 
         link = self.domain + 'OrderOpen'
         
@@ -80,3 +80,14 @@ class API(object):
         response = requests.get(link, headers = {'TOKEN': f'{self.token}'})
         return response.json()
 
+    def bar_chart(self, symbol, timeframe):
+        link = self.domain + 'ChartRequest/' + symbol + '/' + str(timeframe)
+        response = requests.get(link, headers = {'TOKEN': f'{self.token}'})
+        digit = self.symbol_info(symbol)['Digits']
+        result = response.json()
+        for key in range(len(result)):
+            result[key]['Open'] =round(result[key]['Open'] * (10**-digit), digit)
+            result[key]['Close'] = round((result[key]['Close'] * (10**-digit)) + result[key]['Open'], digit)
+            result[key]['High'] = round((result[key]['High'] * (10**-digit)) + result[key]['Open'], digit)
+            result[key]['Low'] = round((result[key]['Low'] * (10**-digit)) + result[key]['Open'], digit)
+        return result
